"use client";

import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import BlurFade from "@/components/ui/blur-fade";
import { Card, CardContent } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { motion } from "framer-motion";
import { useLocale } from "next-intl";


export function ValuesClient() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";
	const { texts } = useBasicInfo();

	return (
		<section className="relative overflow-hidden py-14 bg-custom-background-third">
			<motion.div
				className="pointer-events-none absolute inset-0 z-0 overflow-hidden"
				initial={{ opacity: 0 }}
				animate={{ opacity: 1 }}
				transition={{ duration: 1, delay: 0.5 }}
			>
				<div className="absolute bottom-0 right-0 h-1/3 w-1/2 lg:-bottom-12 lg:h-2/3 lg:w-full">
					<Image
						src={"/wave.png"}
						alt="Wave background"
						fill
						quality={100}
						className="object-cover object-right-bottom"
						style={{
							maskImage:
								"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
							WebkitMaskImage:
								"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
						}}
					/>
				</div>
			</motion.div>

			<div className="container relative mx-auto max-w-7xl px-4 lg:px-8">
				<div className="flex flex-col gap-16 lg:flex-row">
					<div className={cn("w-full lg:w-1/2", isRTL && "text-right")}>
						<Card className="mb-8 bg-custom-background p-6 shadow-md relative">
							<ContentLines
								title={texts?.about_principles_goals?.[0]?.text?.[locale]}
								underlineColor="custom-primary-accent"
								textColor="text-custom-primary-accent"
								padding="none"
							/>
							<div className="mt-6 grid gap-1">
								<div className="space-y-1">
									<p className="text-gray-600 text-[15px]" style={{ whiteSpace: "pre-line" }}>
										{texts?.about_principles_goals?.[0]?.description?.[locale]}
									</p>
								</div>
							</div>
						</Card>

						<div className="grid gap-4 sm:grid-cols-2">
							<Card className="bg-custom-background  h-auto">
								<CardContent className="p-6">
									<h3 className="mb-2 text-lg font-semibold text-custom-primary-accent">
										{texts?.about_principles_goals?.[1]?.text?.[locale]}
									</h3>
									<p className="text-[#646464] text-[13px]">
										{texts?.about_principles_goals?.[1]?.description?.[locale]}
									</p>
								</CardContent>
							</Card>

							<Card className="bg-[#606676] shadow-md h-auto">
								<CardContent className="p-6">
									<h3 className="mb-2 text-lg font-semibold text-white">
										{texts?.about_principles_goals?.[2]?.text?.[locale]}
									</h3>
									<p className="text-white text-[13px]">
										{texts?.about_principles_goals?.[2]?.description?.[locale]}
									</p>
								</CardContent>
							</Card>
						</div>
					</div>

					<BlurFade
						className={cn(
							"relative lg:col-span-5",
							isRTL ? "lg:order-2" : "lg:order-1"
						)}
					>
						<motion.div
							className="absolute -left-4 -top-4 w-full bg-custom-border rounded-lg h-[560px]"
							initial={{ opacity: 0, scale: 0.8 }}
							animate={{ opacity: 1, scale: 1 }}
							transition={{ duration: 0.5 }}
						/>
						<motion.div
							initial={{ opacity: 0, y: 20 }}
							animate={{ opacity: 1, y: 0 }}
							transition={{ duration: 0.5, delay: 0.2 }}
						>
							<Image
								src={ImageBaseUrl + texts?.about_principles_goals_img}
								alt="BinTaleb Logo"
								width={487}
								height={577}
								className="relative z-10 h-[530px] w-[487px] rounded-lg object-cover drop-shadow-[2px_2px_2px_rgba(0,0,0,0.5)] filter"
							/>
						</motion.div>
					</BlurFade>
				</div>
			</div>
		</section>
	);
}
